@@ -2,6 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+#ifdef UNSAFE_BUFFERS_BUILD
+// TODO(crbug.com/40285824): Remove this and spanify to fix the errors.
+#pragma allow_unsafe_buffers
+#endif
+
 #include "media/gpu/v4l2/v4l2_video_decoder_delegate_h264.h"
 
 #include <linux/v4l2-controls.h>
@@ -412,6 +417,11 @@ V4L2VideoDecoderDelegateH264::ParseEncryptedSliceHeader(
     LOG(ERROR) << "Invalid secure buffer";
     return Status::kFail;
   }
+
+  if (encrypted_slice_header_parsing_active_) {
+    return Status::kTryAgain;
+  }
+
   if (encrypted_slice_header_parsing_failed_) {
     encrypted_slice_header_parsing_failed_ = false;
     last_parsed_encrypted_slice_header_.clear();
@@ -425,6 +435,7 @@ V4L2VideoDecoderDelegateH264::ParseEncryptedSliceHeader(
 
   // Send the request for the slice header if we don't have a pending result.
   if (last_parsed_encrypted_slice_header_.empty()) {
+    encrypted_slice_header_parsing_active_ = true;
     cdm_context_->GetChromeOsCdmContext()->ParseEncryptedSliceHeader(
         secure_handle,
         base::checked_cast<uint32_t>(encrypted_slice_header_offset_),
@@ -524,7 +535,7 @@ H264Decoder::H264Accelerator::Status V4L2VideoDecoderDelegateH264::SubmitSlice(
   const size_t data_copy_size = size + 3;
   if (dec_surface->secure_handle()) {
     // If this is multi-slice CENCv1, then we need to increase this offset.
-    encrypted_slice_header_offset_ += size;
+    encrypted_slice_header_offset_ += data_copy_size;
     // The secure world already post-processed the secure buffer so that all of
     // the slice NALUs w/ 3 byte start codes are the only contents.
     return surface_handler_->SubmitSlice(dec_surface.get(), nullptr,
@@ -612,6 +623,7 @@ void V4L2VideoDecoderDelegateH264::Reset() {
   encrypted_slice_header_offset_ = 0;
   last_parsed_encrypted_slice_header_.clear();
   encrypted_slice_header_parsing_failed_ = false;
+  encrypted_slice_header_parsing_active_ = false;
 }
 
 scoped_refptr<V4L2DecodeSurface>
@@ -626,6 +638,7 @@ void V4L2VideoDecoderDelegateH264::OnEncryptedSliceHeaderParsed(
     const std::vector<uint8_t>& parsed_headers) {
   encrypted_slice_header_parsing_failed_ = !status;
   last_parsed_encrypted_slice_header_ = parsed_headers;
+  encrypted_slice_header_parsing_active_ = false;
   surface_handler_->ResumeDecoding();
 }
 
