@@ -12,6 +12,9 @@
 #include <GLES3/gl3.h>
 #include <stdint.h>
 
+#include <array>
+
+#include "base/containers/heap_array.h"
 #include "base/functional/bind.h"
 #include "base/logging.h"
 #include "base/memory/aligned_memory.h"
@@ -81,18 +84,17 @@ scoped_refptr<VideoFrame> CreateTestY16Frame(const gfx::Size& coded_size,
 }
 
 // Readback the contents of a RGBA texture into an array of RGBA values.
-static std::unique_ptr<uint8_t[]> ReadbackTexture(
-    gpu::gles2::GLES2Interface* gl,
-    GLuint texture,
-    const gfx::Size& size) {
+static base::HeapArray<uint8_t> ReadbackTexture(gpu::gles2::GLES2Interface* gl,
+                                                GLuint texture,
+                                                const gfx::Size& size) {
   size_t pixel_count = size.width() * size.height();
   GLuint fbo = 0;
   gl->GenFramebuffers(1, &fbo);
   gl->BindFramebuffer(GL_FRAMEBUFFER, fbo);
   gl->FramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D,
                            texture, 0);
-  auto pixels = std::make_unique<uint8_t[]>(pixel_count * 4);
-  uint8_t* raw_pixels = pixels.get();
+  auto pixels = base::HeapArray<uint8_t>::Uninit(pixel_count * 4);
+  uint8_t* raw_pixels = pixels.data();
   gl->ReadPixels(0, 0, size.width(), size.height(), GL_RGBA, GL_UNSIGNED_BYTE,
                  raw_pixels);
   gl->DeleteFramebuffers(1, &fbo);
@@ -128,6 +130,9 @@ class PaintCanvasVideoRendererTest : public testing::Test {
   // Paints to |canvas| using |renderer_| without any frame data.
   void PaintWithoutFrame(cc::PaintCanvas* canvas);
 
+  // Set `video_frame` to `color`.
+  void FillFrameWithColor(scoped_refptr<VideoFrame> video_frame, Color color);
+
   // Paints the |video_frame| to the |canvas| using |renderer_|, setting the
   // color of |video_frame| to |color| first.
   void Paint(scoped_refptr<VideoFrame> video_frame,
@@ -274,11 +279,30 @@ PaintCanvasVideoRendererTest::PaintCanvasVideoRendererTest()
 
 PaintCanvasVideoRendererTest::~PaintCanvasVideoRendererTest() = default;
 
+void PaintCanvasVideoRendererTest::FillFrameWithColor(
+    scoped_refptr<VideoFrame> video_frame,
+    Color color) {
+  switch (color) {
+    case kNone:
+      break;
+    case kRed:
+      media::FillYUV(video_frame.get(), 76, 84, 255);
+      break;
+    case kGreen:
+      media::FillYUV(video_frame.get(), 149, 43, 21);
+      break;
+    case kBlue:
+      media::FillYUV(video_frame.get(), 29, 255, 107);
+      break;
+  }
+}
+
 void PaintCanvasVideoRendererTest::PaintWithoutFrame(cc::PaintCanvas* canvas) {
   cc::PaintFlags flags;
   flags.setFilterQuality(cc::PaintFlags::FilterQuality::kLow);
-  renderer_.Paint(nullptr, canvas, kNaturalRect, flags, kNoTransformation,
-                  nullptr);
+  PaintCanvasVideoRenderer::PaintParams params;
+  params.dest_rect = kNaturalRect;
+  renderer_.Paint(nullptr, canvas, flags, params, nullptr);
 }
 
 void PaintCanvasVideoRendererTest::Paint(scoped_refptr<VideoFrame> video_frame,
@@ -295,24 +319,14 @@ void PaintCanvasVideoRendererTest::PaintRotated(
     Color color,
     SkBlendMode mode,
     VideoTransformation video_transformation) {
-  switch (color) {
-    case kNone:
-      break;
-    case kRed:
-      media::FillYUV(video_frame.get(), 76, 84, 255);
-      break;
-    case kGreen:
-      media::FillYUV(video_frame.get(), 149, 43, 21);
-      break;
-    case kBlue:
-      media::FillYUV(video_frame.get(), 29, 255, 107);
-      break;
-  }
+  FillFrameWithColor(video_frame, color);
   cc::PaintFlags flags;
   flags.setBlendMode(mode);
   flags.setFilterQuality(cc::PaintFlags::FilterQuality::kLow);
-  renderer_.Paint(std::move(video_frame), canvas, dest_rect, flags,
-                  video_transformation, nullptr);
+  PaintCanvasVideoRenderer::PaintParams params;
+  params.dest_rect = dest_rect;
+  params.transformation = video_transformation;
+  renderer_.Paint(std::move(video_frame), canvas, flags, params, nullptr);
 }
 
 void PaintCanvasVideoRendererTest::Copy(scoped_refptr<VideoFrame> video_frame,
@@ -365,6 +379,24 @@ TEST_F(PaintCanvasVideoRendererTest, CopyTransparentFrame) {
             bitmap()->getColor(0, 0));
 }
 
+TEST_F(PaintCanvasVideoRendererTest, ReinterpretAsSRGB) {
+  FillFrameWithColor(natural_frame(), kRed);
+  natural_frame()->set_color_space(gfx::ColorSpace::CreateHDR10());
+
+  cc::PaintFlags flags;
+  flags.setBlendMode(SkBlendMode::kSrcOver);
+  flags.setFilterQuality(cc::PaintFlags::FilterQuality::kLow);
+
+  PaintCanvasVideoRenderer::PaintParams params;
+  params.dest_rect = kNaturalRect;
+  renderer_.Paint(natural_frame(), target_canvas(), flags, params, nullptr);
+  EXPECT_NE(SK_ColorRED, bitmap()->getColor(0, 0));
+
+  params.reinterpret_as_srgb = true;
+  renderer_.Paint(natural_frame(), target_canvas(), flags, params, nullptr);
+  EXPECT_EQ(SK_ColorRED, bitmap()->getColor(0, 0));
+}
+
 TEST_F(PaintCanvasVideoRendererTest, Natural) {
   Paint(natural_frame(), target_canvas(), kRed);
   EXPECT_EQ(SK_ColorRED, bitmap()->getColor(0, 0));
@@ -444,16 +476,17 @@ TEST_F(PaintCanvasVideoRendererTest, CroppedFrameToRGBParallel) {
   const gfx::Size visible_size = test_frame->visible_rect().size();
   const size_t row_bytes = visible_size.width() * sizeof(SkColor);
   const size_t allocation_size = row_bytes * visible_size.height();
-
-  std::unique_ptr<uint8_t, base::AlignedFreeDeleter> memory(
-      static_cast<uint8_t*>(base::AlignedAlloc(
-          allocation_size, media::VideoFrame::kFrameAddressAlignment)));
-  memset(memory.get(), 0, allocation_size);
+  auto memory =
+      base::HeapArray<uint8_t, base::AlignedFreeDeleter>::FromOwningPointer(
+          static_cast<uint8_t*>(base::AlignedAlloc(
+              allocation_size, media::VideoFrame::kFrameAddressAlignment)),
+          allocation_size);
+  memset(memory.data(), 0, allocation_size);
 
   PaintCanvasVideoRenderer::ConvertVideoFrameToRGBPixels(
-      test_frame.get(), memory.get(), row_bytes);
+      test_frame.get(), memory.data(), row_bytes);
 
-  const uint32_t* rgb_pixels = reinterpret_cast<uint32_t*>(memory.get());
+  const uint32_t* rgb_pixels = reinterpret_cast<uint32_t*>(memory.data());
 
   // Check the corners; this is sufficient to reveal https://crbug.com/1027442.
   EXPECT_EQ(SK_ColorBLACK, rgb_pixels[0]);
@@ -668,20 +701,23 @@ TEST_F(PaintCanvasVideoRendererTest, Y16) {
   const int offset_y = 5;
   const int stride = bitmap.width() + offset_x;
   const size_t byte_size = stride * (bitmap.height() + offset_y) * 2;
-  std::unique_ptr<unsigned char, base::AlignedFreeDeleter> memory(
-      static_cast<unsigned char*>(base::AlignedAlloc(
-          byte_size, media::VideoFrame::kFrameAddressAlignment)));
+  auto memory = base::HeapArray<unsigned char, base::AlignedFreeDeleter>::
+      FromOwningPointer(
+          static_cast<unsigned char*>(base::AlignedAlloc(
+              byte_size, media::VideoFrame::kFrameAddressAlignment)),
+          byte_size);
   const gfx::Rect rect(offset_x, offset_y, bitmap.width(), bitmap.height());
   auto video_frame =
       CreateTestY16Frame(gfx::Size(stride, offset_y + bitmap.height()), rect,
-                         memory.get(), cropped_frame()->timestamp());
+                         memory.data(), cropped_frame()->timestamp());
 
   cc::SkiaPaintCanvas canvas(bitmap);
   cc::PaintFlags flags;
   flags.setFilterQuality(cc::PaintFlags::FilterQuality::kNone);
-  renderer_.Paint(std::move(video_frame), &canvas,
-                  gfx::RectF(bitmap.width(), bitmap.height()), flags,
-                  kNoTransformation, nullptr);
+  PaintCanvasVideoRenderer::PaintParams paint_params;
+  paint_params.dest_rect = gfx::RectF(bitmap.width(), bitmap.height());
+  renderer_.Paint(std::move(video_frame), &canvas, flags, paint_params,
+                  nullptr);
   for (int j = 0; j < bitmap.height(); j++) {
     for (int i = 0; i < bitmap.width(); i++) {
       const int value = i + j * bitmap.width();
@@ -698,12 +734,9 @@ TEST_F(PaintCanvasVideoRendererTest, Yuv420P12OddWidth) {
   constexpr int kImgHeight = 3;
   constexpr int kUvWidth = (kImgWidth + 1) / 2;
   constexpr int kUvHeight = (kImgHeight + 1) / 2;
-  std::unique_ptr<uint16_t[]> y_plane =
-      std::make_unique<uint16_t[]>(kImgWidth * kImgHeight);
-  std::unique_ptr<uint16_t[]> u_plane =
-      std::make_unique<uint16_t[]>(kUvWidth * kUvHeight);
-  std::unique_ptr<uint16_t[]> v_plane =
-      std::make_unique<uint16_t[]>(kUvWidth * kUvHeight);
+  auto y_plane = base::HeapArray<uint16_t>::Uninit(kImgWidth * kImgHeight);
+  auto u_plane = base::HeapArray<uint16_t>::Uninit(kUvWidth * kUvHeight);
+  auto v_plane = base::HeapArray<uint16_t>::Uninit(kUvWidth * kUvHeight);
   // Set all pixels to white.
   for (int i = 0; i < kImgHeight; ++i) {
     for (int j = 0; j < kImgWidth; ++j) {
@@ -718,19 +751,17 @@ TEST_F(PaintCanvasVideoRendererTest, Yuv420P12OddWidth) {
   }
   const int32_t y_stride = sizeof(uint16_t) * kImgWidth;
   const int32_t uv_stride = sizeof(uint16_t) * kUvWidth;
-  uint8_t* const y_data = reinterpret_cast<uint8_t*>(y_plane.get());
-  uint8_t* const u_data = reinterpret_cast<uint8_t*>(u_plane.get());
-  uint8_t* const v_data = reinterpret_cast<uint8_t*>(v_plane.get());
 
   auto size = gfx::Size(kImgWidth, kImgHeight);
   scoped_refptr<VideoFrame> frame = VideoFrame::WrapExternalYuvData(
       PIXEL_FORMAT_YUV420P12, size, gfx::Rect(size), size, y_stride, uv_stride,
-      uv_stride, y_data, u_data, v_data, base::TimeDelta());
+      uv_stride, reinterpret_cast<uint8_t*>(y_plane.data()),
+      reinterpret_cast<uint8_t*>(u_plane.data()),
+      reinterpret_cast<uint8_t*>(v_plane.data()), base::TimeDelta());
 
-  std::unique_ptr<uint32_t[]> rgba =
-      std::make_unique<uint32_t[]>(kImgWidth * kImgHeight);
+  auto rgba = base::HeapArray<uint32_t>::Uninit(kImgWidth * kImgHeight);
   PaintCanvasVideoRenderer::ConvertVideoFrameToRGBPixels(
-      frame.get(), rgba.get(), frame->visible_rect().width() * 4,
+      frame.get(), rgba.data(), frame->visible_rect().width() * 4,
       /*premultiply_alpha=*/true);
   for (int i = 0; i < kImgHeight; ++i) {
     for (int j = 0; j < kImgWidth; ++j) {
@@ -746,17 +777,14 @@ TEST_F(PaintCanvasVideoRendererTest, I420WithFilters) {
   constexpr int kImgHeight = 4;
   constexpr int kUvWidth = (kImgWidth + 1) / 2;
   constexpr int kUvHeight = (kImgHeight + 1) / 2;
-  std::unique_ptr<uint8_t[]> y_plane =
-      std::make_unique<uint8_t[]>(kImgWidth * kImgHeight);
-  std::unique_ptr<uint8_t[]> u_plane =
-      std::make_unique<uint8_t[]>(kUvWidth * kUvHeight);
-  std::unique_ptr<uint8_t[]> v_plane =
-      std::make_unique<uint8_t[]>(kUvWidth * kUvHeight);
+  auto y_plane = base::HeapArray<uint8_t>::Uninit(kImgWidth * kImgHeight);
+  auto u_plane = base::HeapArray<uint8_t>::Uninit(kUvWidth * kUvHeight);
+  auto v_plane = base::HeapArray<uint8_t>::Uninit(kUvWidth * kUvHeight);
   // In the JPEG color space (K_R = 0.299, K_B = 0.114, full range), red
   // (R = 255, G = 0, B = 0) is Y = 76, U = 85, V = 255.
   //
   // Set Y to 76 for all pixels.
-  memset(y_plane.get(), 76, kImgWidth * kImgHeight);
+  memset(y_plane.data(), 76, kImgWidth * kImgHeight);
   // Set U = 85 and V = 255 for the upperleft pixel. Then vary U and V with a
   // linear, diagonal slope over the UV planes with a step size of 4 and -4,
   // respectively.
@@ -788,15 +816,15 @@ TEST_F(PaintCanvasVideoRendererTest, I420WithFilters) {
   auto size = gfx::Size(kImgWidth, kImgHeight);
   scoped_refptr<VideoFrame> frame = VideoFrame::WrapExternalYuvData(
       PIXEL_FORMAT_I420, size, gfx::Rect(size), size, kImgWidth, kUvWidth,
-      kUvWidth, y_plane.get(), u_plane.get(), v_plane.get(), base::TimeDelta());
+      kUvWidth, y_plane.data(), u_plane.data(), v_plane.data(),
+      base::TimeDelta());
   frame->set_color_space(gfx::ColorSpace::CreateJpeg());
 
-  std::unique_ptr<uint32_t[]> rgba =
-      std::make_unique<uint32_t[]>(kImgWidth * kImgHeight);
+  auto rgba = base::HeapArray<uint32_t>::Uninit(kImgWidth * kImgHeight);
 
   // First convert with kFilterNone (nearest neighbor).
   PaintCanvasVideoRenderer::ConvertVideoFrameToRGBPixels(
-      frame.get(), rgba.get(), frame->visible_rect().width() * 4,
+      frame.get(), rgba.data(), frame->visible_rect().width() * 4,
       /*premultiply_alpha=*/true);
 
   // The pixel at coordinates (1, 1) will have U = 89 and V = 251 if nearest
@@ -820,7 +848,7 @@ TEST_F(PaintCanvasVideoRendererTest, I420WithFilters) {
 
   // Then convert with kFilterBilinear (bilinear interpolation).
   PaintCanvasVideoRenderer::ConvertVideoFrameToRGBPixels(
-      frame.get(), rgba.get(), frame->visible_rect().width() * 4,
+      frame.get(), rgba.data(), frame->visible_rect().width() * 4,
       /*premultiply_alpha=*/true, PaintCanvasVideoRenderer::kFilterBilinear);
 
   // The pixel at coordinates (1, 1) will have the correct values U = 93 and
@@ -929,13 +957,15 @@ TEST_F(PaintCanvasVideoRendererTest, ContextLost) {
       gpu::ClientSharedImage::CreateForTesting();
   auto video_frame = VideoFrame::WrapSharedImage(
       PIXEL_FORMAT_NV12, shared_image, gpu::SyncToken(),
-      GL_TEXTURE_RECTANGLE_ARB, base::BindOnce(MailboxHoldersReleased), size,
-      gfx::Rect(size), size, kNoTimestamp);
+      base::BindOnce(MailboxHoldersReleased), size, gfx::Rect(size), size,
+      kNoTimestamp);
 
   cc::PaintFlags flags;
   flags.setFilterQuality(cc::PaintFlags::FilterQuality::kLow);
-  renderer_.Paint(std::move(video_frame), &canvas, kNaturalRect, flags,
-                  kNoTransformation, context_provider.get());
+  PaintCanvasVideoRenderer::PaintParams params;
+  params.dest_rect = kNaturalRect;
+  renderer_.Paint(std::move(video_frame), &canvas, flags, params,
+                  context_provider.get());
 }
 #endif
 
@@ -951,16 +981,16 @@ TEST_F(PaintCanvasVideoRendererTest, CorrectFrameSizeToVisibleRect) {
   gfx::Size coded_size(fWidth, fHeight);
   gfx::Size visible_size(fWidth / 2, fHeight / 2);
 
-  uint8_t memory[fWidth * fHeight * 2] = {0};
+  std::array<uint8_t, fWidth * fHeight * 2> memory = {};
 
   auto video_frame = media::VideoFrame::WrapExternalData(
       media::PIXEL_FORMAT_Y16, coded_size, gfx::Rect(visible_size),
       visible_size, &memory[0], fWidth * fHeight * 2, base::Milliseconds(4));
 
-  gfx::RectF visible_rect(visible_size.width(), visible_size.height());
   cc::PaintFlags flags;
-  renderer_.Paint(std::move(video_frame), &canvas, visible_rect, flags,
-                  kNoTransformation, nullptr);
+  PaintCanvasVideoRenderer::PaintParams params;
+  params.dest_rect = gfx::RectF(visible_size.width(), visible_size.height());
+  renderer_.Paint(std::move(video_frame), &canvas, flags, params, nullptr);
 
   EXPECT_EQ(fWidth / 2, renderer_.LastImageDimensionsForTesting().width());
   EXPECT_EQ(fWidth / 2, renderer_.LastImageDimensionsForTesting().height());
@@ -975,13 +1005,15 @@ TEST_F(PaintCanvasVideoRendererTest, TexImage2D_Y16_RGBA32F) {
   const int height = 16;
   const int stride = width + offset_x;
   const size_t byte_size = stride * (height + offset_y) * 2;
-  std::unique_ptr<unsigned char, base::AlignedFreeDeleter> memory(
-      static_cast<unsigned char*>(base::AlignedAlloc(
-          byte_size, media::VideoFrame::kFrameAddressAlignment)));
+  auto memory = base::HeapArray<unsigned char, base::AlignedFreeDeleter>::
+      FromOwningPointer(
+          static_cast<unsigned char*>(base::AlignedAlloc(
+              byte_size, media::VideoFrame::kFrameAddressAlignment)),
+          byte_size);
   const gfx::Rect rect(offset_x, offset_y, width, height);
   auto video_frame =
       CreateTestY16Frame(gfx::Size(stride, offset_y + height), rect,
-                         memory.get(), cropped_frame()->timestamp());
+                         memory.data(), cropped_frame()->timestamp());
 
   TestGLES2Interface gles2;
   // Bind the texImage2D callback to verify the uint16 to float32 conversion.
@@ -1023,13 +1055,16 @@ TEST_F(PaintCanvasVideoRendererTest, TexSubImage2D_Y16_R32F) {
   const int height = 16;
   const int stride = width + offset_x;
   const size_t byte_size = stride * (height + offset_y) * 2;
-  std::unique_ptr<unsigned char, base::AlignedFreeDeleter> memory(
-      static_cast<unsigned char*>(base::AlignedAlloc(
-          byte_size, media::VideoFrame::kFrameAddressAlignment)));
+  auto memory = base::HeapArray<unsigned char, base::AlignedFreeDeleter>::
+      FromOwningPointer(
+          static_cast<unsigned char*>(base::AlignedAlloc(
+              byte_size, media::VideoFrame::kFrameAddressAlignment)),
+          byte_size);
+
   const gfx::Rect rect(offset_x, offset_y, width, height);
   auto video_frame =
       CreateTestY16Frame(gfx::Size(stride, offset_y + height), rect,
-                         memory.get(), cropped_frame()->timestamp());
+                         memory.data(), cropped_frame()->timestamp());
 
   TestGLES2Interface gles2;
   // Bind the texImage2D callback to verify the uint16 to float32 conversion.
@@ -1108,14 +1143,13 @@ class PaintCanvasVideoRendererWithGLTest : public testing::Test {
     destination_gl->BindTexture(target, texture);
 
     renderer_.CopyVideoFrameTexturesToGLTexture(
-        media_context_.get(), destination_gl,
-        destination_context_->ContextCapabilities(), frame, target, texture,
-        GL_RGBA, GL_RGBA, GL_UNSIGNED_BYTE, 0, false /* premultiply_alpha */,
+        media_context_.get(), destination_gl, frame, target, texture, GL_RGBA,
+        GL_RGBA, GL_UNSIGNED_BYTE, 0, false /* premultiply_alpha */,
         false /* flip_y */);
 
     gfx::Size expected_size = frame->visible_rect().size();
 
-    std::unique_ptr<uint8_t[]> pixels =
+    base::HeapArray<uint8_t> pixels =
         ReadbackTexture(destination_gl, texture, expected_size);
     destination_gl->DeleteTextures(1, &texture);
 
@@ -1124,7 +1158,7 @@ class PaintCanvasVideoRendererWithGLTest : public testing::Test {
           uint8_t* p = pixels + (size.width() * y + x) * 4;
           return SkColorSetARGB(p[3], p[0], p[1], p[2]);
         },
-        pixels.get(), expected_size);
+        pixels.data(), expected_size);
     check_pixels(get_color);
   }
 
@@ -1268,16 +1302,15 @@ TEST_F(PaintCanvasVideoRendererWithGLTest, CopyVideoFrameYUVDataToGLTexture) {
   destination_gl->BindTexture(target, texture);
 
   renderer_.CopyVideoFrameYUVDataToGLTexture(
-      media_context_.get(), destination_gl,
-      destination_context_->ContextCapabilities(), cropped_frame(), target,
-      texture, GL_RGBA, GL_RGBA, GL_UNSIGNED_BYTE, 0,
-      false /* premultiply_alpha */, false /* flip_y */);
+      media_context_.get(), destination_gl, cropped_frame(), target, texture,
+      GL_RGBA, GL_RGBA, GL_UNSIGNED_BYTE, 0, false /* premultiply_alpha */,
+      false /* flip_y */);
 
   gfx::Size expected_size = cropped_frame()->visible_rect().size();
 
-  std::unique_ptr<uint8_t[]> pixels =
+  base::HeapArray<uint8_t> pixels =
       ReadbackTexture(destination_gl, texture, expected_size);
-  auto get_color = ColorGetter(pixels.get(), expected_size);
+  auto get_color = ColorGetter(pixels.data(), expected_size);
 
   // Avoid checking around the seams.
   EXPECT_EQ(SK_ColorBLACK, get_color(0, 0));
@@ -1301,16 +1334,15 @@ TEST_F(PaintCanvasVideoRendererWithGLTest,
   destination_gl->BindTexture(target, texture);
 
   renderer_.CopyVideoFrameYUVDataToGLTexture(
-      media_context_.get(), destination_gl,
-      destination_context_->ContextCapabilities(), cropped_frame(), target,
-      texture, GL_RGBA, GL_RGBA, GL_UNSIGNED_BYTE, 0,
-      false /* premultiply_alpha */, true /* flip_y */);
+      media_context_.get(), destination_gl, cropped_frame(), target, texture,
+      GL_RGBA, GL_RGBA, GL_UNSIGNED_BYTE, 0, false /* premultiply_alpha */,
+      true /* flip_y */);
 
   gfx::Size expected_size = cropped_frame()->visible_rect().size();
 
-  std::unique_ptr<uint8_t[]> pixels =
+  base::HeapArray<uint8_t> pixels =
       ReadbackTexture(destination_gl, texture, expected_size);
-  auto get_color = ColorGetter(pixels.get(), expected_size);
+  auto get_color = ColorGetter(pixels.data(), expected_size);
 
   // Avoid checking around the seams.
   EXPECT_EQ(SK_ColorBLACK, get_color(0, 5));
