@@ -231,13 +231,6 @@ const GetChildIDAtIndex = natives.GetChildIDAtIndex;
  */
 const GetChildIds = natives.GetChildIDs;
 
-/**
- * @param {string} axTreeID The id of the accessibility tree.
- * @param {number} nodeID The id of a node.
- * @return {?Object} An object mapping html attributes to values.
- */
-const GetHtmlAttributes = natives.GetHtmlAttributes;
-
 /**
  * @param {string} axTreeID The id of the accessibility tree.
  * @param {number} nodeID The id of a node.
@@ -397,15 +390,6 @@ const GetIntListAttribute = natives.GetIntListAttribute;
 const GetIntListAttributeReverseRelations =
     natives.GetIntListAttributeReverseRelations;
 
-/**
- * @param {string} axTreeID The id of the accessibility tree.
- * @param {number} nodeID The id of a node.
- * @param {string} attr The name of an HTML attribute.
- * @return {?string} The value of this attribute, or undefined if the tree,
- *     node, or attribute wasn't found.
- */
-const GetHtmlAttribute = natives.GetHtmlAttribute;
-
 /**
  * @param {string} axTreeID The id of the accessibility tree.
  * @param {number} nodeID The id of a node.
@@ -732,10 +716,6 @@ class AutomationNode {
     }
   }
 
-  get htmlAttributes() {
-    return GetHtmlAttributes(this.treeID, this.id) || {};
-  }
-
   get state() {
     return GetState(this.treeID, this.id) || {};
   }
@@ -1530,6 +1510,8 @@ class AutomationNode {
 const stringAttributes = [
   'accessKey',
   'appId',
+  'ariaCellColumnIndexText',
+  'ariaCellRowIndexText',
   'autoComplete',
   'checkedStateDescription',
   'className',
@@ -1539,13 +1521,15 @@ const stringAttributes = [
   'display',
   'doDefaultLabel',
   'fontFamily',
+  'htmlId',
   'htmlTag',
   'imageDataUrl',
-  'innerHtml',
+  'inputType',
   'language',
   'liveRelevant',
   'liveStatus',
   'longClickLabel',
+  'mathContent',
   'placeholder',
   'roleDescription',
   'tooltip',
@@ -1618,8 +1602,6 @@ const nodeRefListAttributes = [
 const floatAttributes =
     ['fontSize', 'maxValueForRange', 'minValueForRange', 'valueForRange'];
 
-const htmlAttributes = [['type', 'inputType']];
-
 const publicAttributes = [];
 
 Array.prototype.forEach.call(stringAttributes, function(attributeName) {
@@ -1756,18 +1738,6 @@ Array.prototype.forEach.call(floatAttributes, function(attributeName) {
   });
 });
 
-Array.prototype.forEach.call(htmlAttributes, function(params) {
-  const srcAttributeName = params[0];
-  const dstAttributeName = params[1];
-  Array.prototype.push.call(publicAttributes, dstAttributeName);
-  Object.defineProperty(AutomationNode.prototype, dstAttributeName, {
-    __proto__: null,
-    get: function() {
-      return GetHtmlAttribute(this.treeID, this.id, srcAttributeName);
-    },
-  });
-});
-
 /**
  * AutomationRootNode.
  *
