@@ -60,6 +60,7 @@
 #include "v8-value.h"
 #include "v8/include/v8-context.h"
 #include "v8/include/v8-function.h"
+#include "v8/include/v8-isolate.h"
 #include "v8/include/v8-object.h"
 #include "v8/include/v8-template.h"
 
@@ -229,6 +230,7 @@ void V8Environment::RequestModuleContents(base::FilePath file_path) {
 
 void V8Environment::OnFileLoaded(std::string module_identifier,
                                  base::File file) {
+  v8::Isolate::Scope isolate_scope(GetIsolate());
   v8::HandleScope handle_scope(GetIsolate());
   Local<Context> context = GetContext();
   Context::Scope context_scope(context);
